@@ -29,6 +29,7 @@ import (
 	"github.com/rs/zerolog/log"
 	vfs "github.com/twpayne/go-vfs/v4"
 	"go.uber.org/multierr"
+	"golang.org/x/exp/maps"
 
 	"github.com/twpayne/chezmoi/v2/pkg/chezmoilog"
 )
@@ -96,12 +97,12 @@ type SourceState struct {
 	logger                  *zerolog.Logger
 	version                 semver.Version
 	mode                    Mode
-	defaultTemplateDataFunc func() map[string]interface{}
+	defaultTemplateDataFunc func() map[string]any
 	templateDataOnly        bool
 	readTemplateData        bool
-	userTemplateData        map[string]interface{}
-	priorityTemplateData    map[string]interface{}
-	templateData            map[string]interface{}
+	userTemplateData        map[string]any
+	priorityTemplateData    map[string]any
+	templateData            map[string]any
 	templateFuncs           template.FuncMap
 	templateOptions         []string
 	templates               map[string]*template.Template
@@ -127,7 +128,7 @@ func WithCacheDir(cacheDirAbsPath AbsPath) SourceStateOption {
 }
 
 // WithDefaultTemplateDataFunc sets the default template data function.
-func WithDefaultTemplateDataFunc(defaultTemplateDataFunc func() map[string]interface{}) SourceStateOption {
+func WithDefaultTemplateDataFunc(defaultTemplateDataFunc func() map[string]any) SourceStateOption {
 	return func(s *SourceState) {
 		s.defaultTemplateDataFunc = defaultTemplateDataFunc
 	}
@@ -176,7 +177,7 @@ func WithMode(mode Mode) SourceStateOption {
 }
 
 // WithPriorityTemplateData adds priority template data.
-func WithPriorityTemplateData(priorityTemplateData map[string]interface{}) SourceStateOption {
+func WithPriorityTemplateData(priorityTemplateData map[string]any) SourceStateOption {
 	return func(s *SourceState) {
 		RecursiveMerge(s.priorityTemplateData, priorityTemplateData)
 	}
@@ -246,8 +247,8 @@ func NewSourceState(options ...SourceStateOption) *SourceState {
 		httpClient:           http.DefaultClient,
 		logger:               &log.Logger,
 		readTemplateData:     true,
-		priorityTemplateData: make(map[string]interface{}),
-		userTemplateData:     make(map[string]interface{}),
+		priorityTemplateData: make(map[string]any),
+		userTemplateData:     make(map[string]any),
 		templateOptions:      DefaultTemplateOptions,
 		templates:            make(map[string]*template.Template),
 		externals:            make(map[RelPath]*External),
@@ -291,10 +292,7 @@ func (s *SourceState) Add(
 		sourceRelPaths []SourceRelPath
 	}
 
-	destAbsPaths := make(AbsPaths, 0, len(destAbsPathInfos))
-	for destAbsPath := range destAbsPathInfos {
-		destAbsPaths = append(destAbsPaths, destAbsPath)
-	}
+	destAbsPaths := AbsPaths(maps.Keys(destAbsPathInfos))
 	sort.Sort(destAbsPaths)
 
 	sourceUpdates := make([]sourceUpdate, 0, len(destAbsPathInfos))
@@ -732,7 +730,7 @@ func (s *SourceState) ExecuteTemplateData(name string, data []byte) ([]byte, err
 
 	// Temporarily set .chezmoi.sourceFile to the name of the template.
 	templateData := s.TemplateData()
-	if chezmoiTemplateData, ok := templateData["chezmoi"].(map[string]interface{}); ok {
+	if chezmoiTemplateData, ok := templateData["chezmoi"].(map[string]any); ok {
 		chezmoiTemplateData["sourceFile"] = name
 		defer delete(chezmoiTemplateData, "sourceFile")
 	}
@@ -1163,9 +1161,9 @@ func (s *SourceState) TargetRelPaths() []RelPath {
 }
 
 // TemplateData returns s's template data.
-func (s *SourceState) TemplateData() map[string]interface{} {
+func (s *SourceState) TemplateData() map[string]any {
 	if s.templateData == nil {
-		s.templateData = make(map[string]interface{})
+		s.templateData = make(map[string]any)
 		if s.defaultTemplateDataFunc != nil {
 			RecursiveMerge(s.templateData, s.defaultTemplateDataFunc())
 			s.defaultTemplateDataFunc = nil
@@ -1229,7 +1227,7 @@ func (s *SourceState) addPatterns(patternSet *patternSet, sourceAbsPath AbsPath,
 	for scanner.Scan() {
 		lineNumber++
 		text := scanner.Text()
-		text, _, _ = CutString(text, "#")
+		text, _, _ = strings.Cut(text, "#")
 		text = strings.TrimSpace(text)
 		if text == "" {
 			continue
@@ -1260,7 +1258,7 @@ func (s *SourceState) addTemplateData(sourceAbsPath AbsPath) error {
 	if err != nil {
 		return fmt.Errorf("%s: %w", sourceAbsPath, err)
 	}
-	var templateData map[string]interface{}
+	var templateData map[string]any
 	if err := format.Unmarshal(data, &templateData); err != nil {
 		return fmt.Errorf("%s: %w", sourceAbsPath, err)
 	}
