@@ -28,8 +28,8 @@ func TestSourceStateAdd(t *testing.T) {
 		name         string
 		destAbsPaths []AbsPath
 		addOptions   AddOptions
-		extraRoot    interface{}
-		tests        []interface{}
+		extraRoot    any
+		tests        []any
 	}{
 		{
 			name: "dir",
@@ -39,7 +39,7 @@ func TestSourceStateAdd(t *testing.T) {
 			addOptions: AddOptions{
 				Include: NewEntryTypeSet(EntryTypesAll),
 			},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.local/share/chezmoi/dot_dir",
 					vfst.TestIsDir,
 					vfst.TestModePerm(0o777&^chezmoitest.Umask),
@@ -60,12 +60,12 @@ func TestSourceStateAdd(t *testing.T) {
 			addOptions: AddOptions{
 				Include: NewEntryTypeSet(EntryTypesAll),
 			},
-			extraRoot: map[string]interface{}{
-				"/home/user": map[string]interface{}{
+			extraRoot: map[string]any{
+				"/home/user": map[string]any{
 					".local/share/chezmoi/exact_dot_dir/file": "# contents of .dir/file\n",
 				},
 			},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.local/share/chezmoi/exact_dot_dir",
 					vfst.TestDoesNotExist,
 				),
@@ -88,7 +88,7 @@ func TestSourceStateAdd(t *testing.T) {
 			addOptions: AddOptions{
 				Include: NewEntryTypeSet(EntryTypesAll),
 			},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.local/share/chezmoi/dot_dir",
 					vfst.TestIsDir,
 					vfst.TestModePerm(0o777&^chezmoitest.Umask),
@@ -108,10 +108,10 @@ func TestSourceStateAdd(t *testing.T) {
 			addOptions: AddOptions{
 				Include: NewEntryTypeSet(EntryTypesAll),
 			},
-			extraRoot: map[string]interface{}{
+			extraRoot: map[string]any{
 				"/home/user/.local/share/chezmoi/dot_dir": &vfst.Dir{Perm: 0o777},
 			},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.local/share/chezmoi/dot_dir/file",
 					vfst.TestModeIsRegular,
 					vfst.TestContentsString("# contents of .dir/file\n"),
@@ -126,7 +126,7 @@ func TestSourceStateAdd(t *testing.T) {
 			addOptions: AddOptions{
 				Include: NewEntryTypeSet(EntryTypesAll),
 			},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.local/share/chezmoi/dot_dir",
 					vfst.TestIsDir,
 					vfst.TestModePerm(0o777&^chezmoitest.Umask),
@@ -148,7 +148,7 @@ func TestSourceStateAdd(t *testing.T) {
 			addOptions: AddOptions{
 				Include: NewEntryTypeSet(EntryTypesAll),
 			},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.local/share/chezmoi/dot_dir",
 					vfst.TestIsDir,
 					vfst.TestModePerm(0o777&^chezmoitest.Umask),
@@ -175,10 +175,10 @@ func TestSourceStateAdd(t *testing.T) {
 			addOptions: AddOptions{
 				Include: NewEntryTypeSet(EntryTypesAll),
 			},
-			extraRoot: map[string]interface{}{
+			extraRoot: map[string]any{
 				"/home/user/.local/share/chezmoi/dot_dir/subdir": &vfst.Dir{Perm: 0o777},
 			},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.local/share/chezmoi/dot_dir/subdir/file",
 					vfst.TestModeIsRegular,
 					vfst.TestContentsString("# contents of .dir/subdir/file\n"),
@@ -193,10 +193,10 @@ func TestSourceStateAdd(t *testing.T) {
 			addOptions: AddOptions{
 				Include: NewEntryTypeSet(EntryTypesAll),
 			},
-			extraRoot: map[string]interface{}{
+			extraRoot: map[string]any{
 				"/home/user/.readonly_dir": &vfst.Dir{Perm: 0o555},
 			},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.local/share/chezmoi/readonly_dot_readonly_dir",
 					vfst.TestIsDir,
 					vfst.TestModePerm(0o777&^chezmoitest.Umask),
@@ -211,7 +211,7 @@ func TestSourceStateAdd(t *testing.T) {
 			addOptions: AddOptions{
 				Include: NewEntryTypeSet(EntryTypesAll),
 			},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.local/share/chezmoi/dot_empty",
 					vfst.TestDoesNotExist,
 				),
@@ -225,7 +225,7 @@ func TestSourceStateAdd(t *testing.T) {
 			addOptions: AddOptions{
 				Include: NewEntryTypeSet(EntryTypesAll),
 			},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.local/share/chezmoi/empty_dot_empty",
 					vfst.TestModeIsRegular,
 					vfst.TestModePerm(0o666&^chezmoitest.Umask),
@@ -241,7 +241,7 @@ func TestSourceStateAdd(t *testing.T) {
 			addOptions: AddOptions{
 				Include: NewEntryTypeSet(EntryTypesAll),
 			},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.local/share/chezmoi/executable_dot_executable",
 					vfst.TestModeIsRegular,
 					vfst.TestModePerm(0o666&^chezmoitest.Umask),
@@ -257,7 +257,7 @@ func TestSourceStateAdd(t *testing.T) {
 			addOptions: AddOptions{
 				Include: NewEntryTypeSet(EntryTypesAll),
 			},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.local/share/chezmoi/dot_executable",
 					vfst.TestModeIsRegular,
 					vfst.TestModePerm(0o666&^chezmoitest.Umask),
@@ -274,7 +274,7 @@ func TestSourceStateAdd(t *testing.T) {
 				Create:  true,
 				Include: NewEntryTypeSet(EntryTypesAll),
 			},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.local/share/chezmoi/create_dot_create",
 					vfst.TestModeIsRegular,
 					vfst.TestModePerm(0o666&^chezmoitest.Umask),
@@ -290,7 +290,7 @@ func TestSourceStateAdd(t *testing.T) {
 			addOptions: AddOptions{
 				Include: NewEntryTypeSet(EntryTypesAll),
 			},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.local/share/chezmoi/dot_file",
 					vfst.TestModeIsRegular,
 					vfst.TestModePerm(0o666&^chezmoitest.Umask),
@@ -306,10 +306,10 @@ func TestSourceStateAdd(t *testing.T) {
 			addOptions: AddOptions{
 				Include: NewEntryTypeSet(EntryTypesAll),
 			},
-			extraRoot: map[string]interface{}{
+			extraRoot: map[string]any{
 				"/home/user/.local/share/chezmoi/executable_dot_file": "# contents of .file\n",
 			},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.local/share/chezmoi/dot_file",
 					vfst.TestModeIsRegular,
 					vfst.TestModePerm(0o666&^chezmoitest.Umask),
@@ -328,10 +328,10 @@ func TestSourceStateAdd(t *testing.T) {
 			addOptions: AddOptions{
 				Include: NewEntryTypeSet(EntryTypesAll),
 			},
-			extraRoot: map[string]interface{}{
+			extraRoot: map[string]any{
 				"/home/user/.local/share/chezmoi/dot_file": "# old contents of .file\n",
 			},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.local/share/chezmoi/dot_file",
 					vfst.TestModeIsRegular,
 					vfst.TestModePerm(0o666&^chezmoitest.Umask),
@@ -347,7 +347,7 @@ func TestSourceStateAdd(t *testing.T) {
 			addOptions: AddOptions{
 				Include: NewEntryTypeSet(EntryTypesAll),
 			},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.local/share/chezmoi/private_dot_private",
 					vfst.TestModeIsRegular,
 					vfst.TestModePerm(0o666&^chezmoitest.Umask),
@@ -363,7 +363,7 @@ func TestSourceStateAdd(t *testing.T) {
 			addOptions: AddOptions{
 				Include: NewEntryTypeSet(EntryTypesAll),
 			},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.local/share/chezmoi/dot_private",
 					vfst.TestModeIsRegular,
 					vfst.TestModePerm(0o666&^chezmoitest.Umask),
@@ -379,13 +379,13 @@ func TestSourceStateAdd(t *testing.T) {
 			addOptions: AddOptions{
 				Include: NewEntryTypeSet(EntryTypesAll),
 			},
-			extraRoot: map[string]interface{}{
+			extraRoot: map[string]any{
 				"/home/user/.readonly": &vfst.File{
 					Perm:     0o444,
 					Contents: []byte("# contents of .readonly\n"),
 				},
 			},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.local/share/chezmoi/readonly_dot_readonly",
 					vfst.TestModeIsRegular,
 					vfst.TestModePerm(0o666&^chezmoitest.Umask),
@@ -401,7 +401,7 @@ func TestSourceStateAdd(t *testing.T) {
 			addOptions: AddOptions{
 				Include: NewEntryTypeSet(EntryTypesAll),
 			},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.local/share/chezmoi/symlink_dot_symlink",
 					vfst.TestModeIsRegular,
 					vfst.TestContentsString(".dir/subdir/file\n"),
@@ -416,12 +416,12 @@ func TestSourceStateAdd(t *testing.T) {
 			addOptions: AddOptions{
 				Include: NewEntryTypeSet(EntryTypesAll),
 			},
-			extraRoot: map[string]interface{}{
-				"/home/user": map[string]interface{}{
+			extraRoot: map[string]any{
+				"/home/user": map[string]any{
 					".symlink_windows": &vfst.Symlink{Target: ".dir\\subdir\\file"},
 				},
 			},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.local/share/chezmoi/symlink_dot_symlink_windows",
 					vfst.TestModeIsRegular,
 					vfst.TestContentsString(".dir/subdir/file\n"),
@@ -437,7 +437,7 @@ func TestSourceStateAdd(t *testing.T) {
 				AutoTemplate: true,
 				Include:      NewEntryTypeSet(EntryTypesAll),
 			},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.local/share/chezmoi/dot_template.tmpl",
 					vfst.TestModeIsRegular,
 					vfst.TestModePerm(0o666&^chezmoitest.Umask),
@@ -454,7 +454,7 @@ func TestSourceStateAdd(t *testing.T) {
 			addOptions: AddOptions{
 				Include: NewEntryTypeSet(EntryTypesAll),
 			},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.local/share/chezmoi/dot_dir",
 					vfst.TestIsDir,
 					vfst.TestModePerm(0o777&^chezmoitest.Umask),
@@ -474,10 +474,10 @@ func TestSourceStateAdd(t *testing.T) {
 			addOptions: AddOptions{
 				Include: NewEntryTypeSet(EntryTypesAll),
 			},
-			extraRoot: map[string]interface{}{
+			extraRoot: map[string]any{
 				"/home/user/.local/share/chezmoi/dot_dir/exact_subdir": &vfst.Dir{Perm: 0o777},
 			},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.local/share/chezmoi/dot_dir/exact_subdir/file",
 					vfst.TestModeIsRegular,
 					vfst.TestContentsString("# contents of .dir/subdir/file\n"),
@@ -488,12 +488,12 @@ func TestSourceStateAdd(t *testing.T) {
 		t.Run(tc.name, func(t *testing.T) {
 			chezmoitest.SkipUnlessGOOS(t, tc.name)
 
-			chezmoitest.WithTestFS(t, map[string]interface{}{
-				"/home/user": map[string]interface{}{
+			chezmoitest.WithTestFS(t, map[string]any{
+				"/home/user": map[string]any{
 					".create": "# contents of .create\n",
-					".dir": map[string]interface{}{
+					".dir": map[string]any{
 						"file": "# contents of .dir/file\n",
-						"subdir": map[string]interface{}{
+						"subdir": map[string]any{
 							"file": "# contents of .dir/subdir/file\n",
 						},
 					},
@@ -503,8 +503,8 @@ func TestSourceStateAdd(t *testing.T) {
 						Contents: []byte("# contents of .executable\n"),
 					},
 					".file": "# contents of .file\n",
-					".local": map[string]interface{}{
-						"share": map[string]interface{}{
+					".local": map[string]any{
+						"share": map[string]any{
 							"chezmoi": &vfst.Dir{Perm: 0o777},
 						},
 					},
@@ -528,7 +528,7 @@ func TestSourceStateAdd(t *testing.T) {
 					WithDestDir(NewAbsPath("/home/user")),
 					WithSourceDir(NewAbsPath("/home/user/.local/share/chezmoi")),
 					WithSystem(system),
-					withUserTemplateData(map[string]interface{}{
+					withUserTemplateData(map[string]any{
 						"variable": "value",
 					}),
 				)
@@ -561,10 +561,10 @@ func TestSourceStateAddInExternal(t *testing.T) {
 	}))
 	defer httpServer.Close()
 
-	root := map[string]interface{}{
-		"/home/user": map[string]interface{}{
+	root := map[string]any{
+		"/home/user": map[string]any{
 			".dir/file2": "# contents of .dir/file2\n",
-			".local/share/chezmoi": map[string]interface{}{
+			".local/share/chezmoi": map[string]any{
 				".chezmoiexternal.toml": chezmoitest.JoinLines(
 					`[".dir"]`,
 					`    type = "archive"`,
@@ -616,28 +616,28 @@ func TestSourceStateAddInExternal(t *testing.T) {
 func TestSourceStateApplyAll(t *testing.T) {
 	for _, tc := range []struct {
 		name               string
-		root               interface{}
+		root               any
 		sourceStateOptions []SourceStateOption
-		tests              []interface{}
+		tests              []any
 	}{
 		{
 			name: "empty",
-			root: map[string]interface{}{
-				"/home/user": map[string]interface{}{
+			root: map[string]any{
+				"/home/user": map[string]any{
 					".local/share/chezmoi": &vfst.Dir{Perm: 0o777},
 				},
 			},
 		},
 		{
 			name: "dir",
-			root: map[string]interface{}{
-				"/home/user": map[string]interface{}{
-					".local/share/chezmoi": map[string]interface{}{
+			root: map[string]any{
+				"/home/user": map[string]any{
+					".local/share/chezmoi": map[string]any{
 						"dot_dir": &vfst.Dir{Perm: 0o777},
 					},
 				},
 			},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.dir",
 					vfst.TestIsDir,
 					vfst.TestModePerm(0o777&^chezmoitest.Umask),
@@ -646,17 +646,17 @@ func TestSourceStateApplyAll(t *testing.T) {
 		},
 		{
 			name: "dir_exact",
-			root: map[string]interface{}{
-				"/home/user": map[string]interface{}{
-					".dir": map[string]interface{}{
+			root: map[string]any{
+				"/home/user": map[string]any{
+					".dir": map[string]any{
 						"file": "# contents of .dir/file\n",
 					},
-					".local/share/chezmoi": map[string]interface{}{
+					".local/share/chezmoi": map[string]any{
 						"exact_dot_dir": &vfst.Dir{Perm: 0o777},
 					},
 				},
 			},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.dir",
 					vfst.TestIsDir,
 					vfst.TestModePerm(0o777&^chezmoitest.Umask),
@@ -668,14 +668,14 @@ func TestSourceStateApplyAll(t *testing.T) {
 		},
 		{
 			name: "file",
-			root: map[string]interface{}{
-				"/home/user": map[string]interface{}{
-					".local/share/chezmoi": map[string]interface{}{
+			root: map[string]any{
+				"/home/user": map[string]any{
+					".local/share/chezmoi": map[string]any{
 						"dot_file": "# contents of .file\n",
 					},
 				},
 			},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.file",
 					vfst.TestModeIsRegular,
 					vfst.TestModePerm(0o666&^chezmoitest.Umask),
@@ -685,15 +685,15 @@ func TestSourceStateApplyAll(t *testing.T) {
 		},
 		{
 			name: "file_remove_empty",
-			root: map[string]interface{}{
-				"/home/user": map[string]interface{}{
+			root: map[string]any{
+				"/home/user": map[string]any{
 					".empty": "# contents of .empty\n",
-					".local/share/chezmoi": map[string]interface{}{
+					".local/share/chezmoi": map[string]any{
 						"dot_empty": "",
 					},
 				},
 			},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.empty",
 					vfst.TestDoesNotExist,
 				),
@@ -701,14 +701,14 @@ func TestSourceStateApplyAll(t *testing.T) {
 		},
 		{
 			name: "file_create_empty",
-			root: map[string]interface{}{
-				"/home/user": map[string]interface{}{
-					".local/share/chezmoi": map[string]interface{}{
+			root: map[string]any{
+				"/home/user": map[string]any{
+					".local/share/chezmoi": map[string]any{
 						"empty_dot_empty": "",
 					},
 				},
 			},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.empty",
 					vfst.TestModeIsRegular,
 					vfst.TestModePerm(0o666&^chezmoitest.Umask),
@@ -718,19 +718,19 @@ func TestSourceStateApplyAll(t *testing.T) {
 		},
 		{
 			name: "file_template",
-			root: map[string]interface{}{
-				"/home/user": map[string]interface{}{
-					".local/share/chezmoi": map[string]interface{}{
+			root: map[string]any{
+				"/home/user": map[string]any{
+					".local/share/chezmoi": map[string]any{
 						"dot_template.tmpl": "key = {{ .variable }}\n",
 					},
 				},
 			},
 			sourceStateOptions: []SourceStateOption{
-				withUserTemplateData(map[string]interface{}{
+				withUserTemplateData(map[string]any{
 					"variable": "value",
 				}),
 			},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.template",
 					vfst.TestModeIsRegular,
 					vfst.TestModePerm(0o666&^chezmoitest.Umask),
@@ -740,14 +740,14 @@ func TestSourceStateApplyAll(t *testing.T) {
 		},
 		{
 			name: "create",
-			root: map[string]interface{}{
-				"/home/user": map[string]interface{}{
-					".local/share/chezmoi": map[string]interface{}{
+			root: map[string]any{
+				"/home/user": map[string]any{
+					".local/share/chezmoi": map[string]any{
 						"create_dot_create": "# contents of .create\n",
 					},
 				},
 			},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.create",
 					vfst.TestModeIsRegular,
 					vfst.TestModePerm(0o666&^chezmoitest.Umask),
@@ -757,15 +757,15 @@ func TestSourceStateApplyAll(t *testing.T) {
 		},
 		{
 			name: "create_no_replace",
-			root: map[string]interface{}{
-				"/home/user": map[string]interface{}{
-					".local/share/chezmoi": map[string]interface{}{
+			root: map[string]any{
+				"/home/user": map[string]any{
+					".local/share/chezmoi": map[string]any{
 						"create_dot_create": "# contents of .create\n",
 					},
 					".create": "# existing contents of .create\n",
 				},
 			},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.create",
 					vfst.TestModeIsRegular,
 					vfst.TestModePerm(0o666&^chezmoitest.Umask),
@@ -775,14 +775,14 @@ func TestSourceStateApplyAll(t *testing.T) {
 		},
 		{
 			name: "symlink",
-			root: map[string]interface{}{
-				"/home/user": map[string]interface{}{
-					".local/share/chezmoi": map[string]interface{}{
+			root: map[string]any{
+				"/home/user": map[string]any{
+					".local/share/chezmoi": map[string]any{
 						"symlink_dot_symlink": ".dir/subdir/file\n",
 					},
 				},
 			},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.symlink",
 					vfst.TestModeType(fs.ModeSymlink),
 					vfst.TestSymlinkTarget(filepath.FromSlash(".dir/subdir/file")),
@@ -791,14 +791,14 @@ func TestSourceStateApplyAll(t *testing.T) {
 		},
 		{
 			name: "symlink_template",
-			root: map[string]interface{}{
-				"/home/user": map[string]interface{}{
-					".local/share/chezmoi": map[string]interface{}{
+			root: map[string]any{
+				"/home/user": map[string]any{
+					".local/share/chezmoi": map[string]any{
 						"symlink_dot_symlink.tmpl": `{{ ".dir/subdir/file" }}` + "\n",
 					},
 				},
 			},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.symlink",
 					vfst.TestModeType(fs.ModeSymlink),
 					vfst.TestSymlinkTarget(filepath.FromSlash(".dir/subdir/file")),
@@ -835,21 +835,21 @@ func TestSourceStateApplyAll(t *testing.T) {
 func TestSourceStateRead(t *testing.T) {
 	for _, tc := range []struct {
 		name                string
-		root                interface{}
+		root                any
 		expectedError       string
 		expectedSourceState *SourceState
 	}{
 		{
 			name: "empty",
-			root: map[string]interface{}{
+			root: map[string]any{
 				"/home/user/.local/share/chezmoi": &vfst.Dir{Perm: 0o777},
 			},
 			expectedSourceState: NewSourceState(),
 		},
 		{
 			name: "dir",
-			root: map[string]interface{}{
-				"/home/user/.local/share/chezmoi": map[string]interface{}{
+			root: map[string]any{
+				"/home/user/.local/share/chezmoi": map[string]any{
 					"dir": &vfst.Dir{
 						Perm: 0o777 &^ chezmoitest.Umask,
 					},
@@ -872,8 +872,8 @@ func TestSourceStateRead(t *testing.T) {
 		},
 		{
 			name: "file",
-			root: map[string]interface{}{
-				"/home/user/.local/share/chezmoi": map[string]interface{}{
+			root: map[string]any{
+				"/home/user/.local/share/chezmoi": map[string]any{
 					"dot_file": "# contents of .file\n",
 				},
 			},
@@ -897,8 +897,8 @@ func TestSourceStateRead(t *testing.T) {
 		},
 		{
 			name: "duplicate_target_file",
-			root: map[string]interface{}{
-				"/home/user/.local/share/chezmoi": map[string]interface{}{
+			root: map[string]any{
+				"/home/user/.local/share/chezmoi": map[string]any{
 					"dot_file":      "# contents of .file\n",
 					"dot_file.tmpl": "# contents of .file\n",
 				},
@@ -907,8 +907,8 @@ func TestSourceStateRead(t *testing.T) {
 		},
 		{
 			name: "duplicate_target_dir",
-			root: map[string]interface{}{
-				"/home/user/.local/share/chezmoi": map[string]interface{}{
+			root: map[string]any{
+				"/home/user/.local/share/chezmoi": map[string]any{
 					"dir": &vfst.Dir{
 						Perm: 0o777 &^ chezmoitest.Umask,
 					},
@@ -921,8 +921,8 @@ func TestSourceStateRead(t *testing.T) {
 		},
 		{
 			name: "duplicate_target_script",
-			root: map[string]interface{}{
-				"/home/user/.local/share/chezmoi": map[string]interface{}{
+			root: map[string]any{
+				"/home/user/.local/share/chezmoi": map[string]any{
 					"run_script":      "#!/bin/sh\n",
 					"run_once_script": "#!/bin/sh\n",
 				},
@@ -931,8 +931,8 @@ func TestSourceStateRead(t *testing.T) {
 		},
 		{
 			name: "symlink_with_attr",
-			root: map[string]interface{}{
-				"/home/user/.local/share/chezmoi": map[string]interface{}{
+			root: map[string]any{
+				"/home/user/.local/share/chezmoi": map[string]any{
 					".file":               "# contents of .file\n",
 					"executable_dot_file": &vfst.Symlink{Target: ".file"},
 				},
@@ -958,8 +958,8 @@ func TestSourceStateRead(t *testing.T) {
 		},
 		{
 			name: "symlink_script",
-			root: map[string]interface{}{
-				"/home/user/.local/share/chezmoi": map[string]interface{}{
+			root: map[string]any{
+				"/home/user/.local/share/chezmoi": map[string]any{
 					".script":    "# contents of .script\n",
 					"run_script": &vfst.Symlink{Target: ".script"},
 				},
@@ -984,8 +984,8 @@ func TestSourceStateRead(t *testing.T) {
 		},
 		{
 			name: "script",
-			root: map[string]interface{}{
-				"/home/user/.local/share/chezmoi": map[string]interface{}{
+			root: map[string]any{
+				"/home/user/.local/share/chezmoi": map[string]any{
 					"run_script": "# contents of script\n",
 				},
 			},
@@ -1009,8 +1009,8 @@ func TestSourceStateRead(t *testing.T) {
 		},
 		{
 			name: "symlink",
-			root: map[string]interface{}{
-				"/home/user/.local/share/chezmoi": map[string]interface{}{
+			root: map[string]any{
+				"/home/user/.local/share/chezmoi": map[string]any{
 					"symlink_dot_symlink": ".dir/subdir/file",
 				},
 			},
@@ -1033,9 +1033,9 @@ func TestSourceStateRead(t *testing.T) {
 		},
 		{
 			name: "file_in_dir",
-			root: map[string]interface{}{
-				"/home/user/.local/share/chezmoi": map[string]interface{}{
-					"dir": map[string]interface{}{
+			root: map[string]any{
+				"/home/user/.local/share/chezmoi": map[string]any{
+					"dir": map[string]any{
 						"file": "# contents of .dir/file\n",
 					},
 				},
@@ -1070,8 +1070,8 @@ func TestSourceStateRead(t *testing.T) {
 		},
 		{
 			name: "chezmoiignore",
-			root: map[string]interface{}{
-				"/home/user/.local/share/chezmoi": map[string]interface{}{
+			root: map[string]any{
+				"/home/user/.local/share/chezmoi": map[string]any{
 					".chezmoiignore": "README.md\n",
 				},
 			},
@@ -1085,8 +1085,8 @@ func TestSourceStateRead(t *testing.T) {
 		},
 		{
 			name: "chezmoiignore_ignore_file",
-			root: map[string]interface{}{
-				"/home/user/.local/share/chezmoi": map[string]interface{}{
+			root: map[string]any{
+				"/home/user/.local/share/chezmoi": map[string]any{
 					".chezmoiignore": "README.md\n",
 					"README.md":      "",
 				},
@@ -1104,15 +1104,15 @@ func TestSourceStateRead(t *testing.T) {
 		},
 		{
 			name: "chezmoiignore_exact_dir",
-			root: map[string]interface{}{
-				"/home/user/dir": map[string]interface{}{
+			root: map[string]any{
+				"/home/user/dir": map[string]any{
 					"file1": "# contents of dir/file1\n",
 					"file2": "# contents of dir/file2\n",
 					"file3": "# contents of dir/file3\n",
 				},
-				"/home/user/.local/share/chezmoi": map[string]interface{}{
+				"/home/user/.local/share/chezmoi": map[string]any{
 					".chezmoiignore": "dir/file3\n",
-					"exact_dir": map[string]interface{}{
+					"exact_dir": map[string]any{
 						"file1": "# contents of dir/file1\n",
 					},
 				},
@@ -1161,9 +1161,9 @@ func TestSourceStateRead(t *testing.T) {
 		},
 		{
 			name: "chezmoiremove",
-			root: map[string]interface{}{
+			root: map[string]any{
 				"/home/user/file": "",
-				"/home/user/.local/share/chezmoi": map[string]interface{}{
+				"/home/user/.local/share/chezmoi": map[string]any{
 					".chezmoiremove": "file\n",
 				},
 			},
@@ -1184,12 +1184,12 @@ func TestSourceStateRead(t *testing.T) {
 		},
 		{
 			name: "chezmoiremove_and_ignore",
-			root: map[string]interface{}{
-				"/home/user": map[string]interface{}{
+			root: map[string]any{
+				"/home/user": map[string]any{
 					"file1": "",
 					"file2": "",
 				},
-				"/home/user/.local/share/chezmoi": map[string]interface{}{
+				"/home/user/.local/share/chezmoi": map[string]any{
 					".chezmoiignore": "file2\n",
 					".chezmoiremove": "file*\n",
 				},
@@ -1219,14 +1219,14 @@ func TestSourceStateRead(t *testing.T) {
 		},
 		{
 			name: "chezmoiremove_and_ignore_in_subdir",
-			root: map[string]interface{}{
-				"/home/user": map[string]interface{}{
-					"dir": map[string]interface{}{
+			root: map[string]any{
+				"/home/user": map[string]any{
+					"dir": map[string]any{
 						"file1": "",
 						"file2": "",
 					},
 				},
-				"/home/user/.local/share/chezmoi": map[string]interface{}{
+				"/home/user/.local/share/chezmoi": map[string]any{
 					"dir/.chezmoiignore": "file2\n",
 					"dir/.chezmoiremove": "file*\n",
 				},
@@ -1266,9 +1266,9 @@ func TestSourceStateRead(t *testing.T) {
 		},
 		{
 			name: "chezmoitemplates",
-			root: map[string]interface{}{
-				"/home/user/.local/share/chezmoi": map[string]interface{}{
-					".chezmoitemplates": map[string]interface{}{
+			root: map[string]any{
+				"/home/user/.local/share/chezmoi": map[string]any{
+					".chezmoitemplates": map[string]any{
 						"template": "# contents of .chezmoitemplates/template\n",
 					},
 				},
@@ -1283,8 +1283,8 @@ func TestSourceStateRead(t *testing.T) {
 		},
 		{
 			name: "chezmoiversion",
-			root: map[string]interface{}{
-				"/home/user/.local/share/chezmoi": map[string]interface{}{
+			root: map[string]any{
+				"/home/user/.local/share/chezmoi": map[string]any{
 					".chezmoiversion": "1.2.3\n",
 				},
 			},
@@ -1292,10 +1292,10 @@ func TestSourceStateRead(t *testing.T) {
 		},
 		{
 			name: "chezmoiversion_multiple",
-			root: map[string]interface{}{
-				"/home/user/.local/share/chezmoi": map[string]interface{}{
+			root: map[string]any{
+				"/home/user/.local/share/chezmoi": map[string]any{
 					".chezmoiversion": "1.2.3\n",
-					"dir": map[string]interface{}{
+					"dir": map[string]any{
 						".chezmoiversion": "2.3.4\n",
 					},
 				},
@@ -1304,9 +1304,9 @@ func TestSourceStateRead(t *testing.T) {
 		},
 		{
 			name: "ignore_dir",
-			root: map[string]interface{}{
-				"/home/user/.local/share/chezmoi": map[string]interface{}{
-					".dir": map[string]interface{}{
+			root: map[string]any{
+				"/home/user/.local/share/chezmoi": map[string]any{
+					".dir": map[string]any{
 						"file": "# contents of .dir/file\n",
 					},
 				},
@@ -1315,8 +1315,8 @@ func TestSourceStateRead(t *testing.T) {
 		},
 		{
 			name: "ignore_file",
-			root: map[string]interface{}{
-				"/home/user/.local/share/chezmoi": map[string]interface{}{
+			root: map[string]any{
+				"/home/user/.local/share/chezmoi": map[string]any{
 					".file": "# contents of .file\n",
 				},
 			},
@@ -1368,13 +1368,13 @@ func TestSourceStateReadExternal(t *testing.T) {
 
 	for _, tc := range []struct {
 		name              string
-		root              interface{}
+		root              any
 		expectedExternals map[RelPath]*External
 	}{
 		{
 			name: "external_yaml",
-			root: map[string]interface{}{
-				"/home/user/.local/share/chezmoi": map[string]interface{}{
+			root: map[string]any{
+				"/home/user/.local/share/chezmoi": map[string]any{
 					".chezmoiexternal.yaml": chezmoitest.JoinLines(
 						`file:`,
 						`    type: "file"`,
@@ -1392,8 +1392,8 @@ func TestSourceStateReadExternal(t *testing.T) {
 		},
 		{
 			name: "external_toml",
-			root: map[string]interface{}{
-				"/home/user/.local/share/chezmoi": map[string]interface{}{
+			root: map[string]any{
+				"/home/user/.local/share/chezmoi": map[string]any{
 					".chezmoiexternal.toml": chezmoitest.JoinLines(
 						`[file]`,
 						`    type = "file"`,
@@ -1411,8 +1411,8 @@ func TestSourceStateReadExternal(t *testing.T) {
 		},
 		{
 			name: "external_in_subdir",
-			root: map[string]interface{}{
-				"/home/user/.local/share/chezmoi/dot_dir": map[string]interface{}{
+			root: map[string]any{
+				"/home/user/.local/share/chezmoi/dot_dir": map[string]any{
 					".chezmoiexternal.yaml": chezmoitest.JoinLines(
 						`file:`,
 						`    type: "file"`,
@@ -1450,14 +1450,14 @@ func TestSourceStateReadExternal(t *testing.T) {
 func TestSourceStateReadScriptsConcurrent(t *testing.T) {
 	for _, tc := range []struct {
 		name string
-		root interface{}
+		root any
 	}{
 		{
 			name: "with_ignore",
-			root: map[string]interface{}{
-				"/home/user/.local/share/chezmoi": map[string]interface{}{
+			root: map[string]any{
+				"/home/user/.local/share/chezmoi": map[string]any{
 					".chezmoiignore": ".chezmoiscripts/linux/**\n",
-					".chezmoiscripts": map[string]interface{}{
+					".chezmoiscripts": map[string]any{
 						"linux":  manyScripts(1000),
 						"darwin": manyScripts(1000),
 					},
@@ -1505,8 +1505,8 @@ func TestSourceStateReadExternalCache(t *testing.T) {
 		},
 	}
 
-	chezmoitest.WithTestFS(t, map[string]interface{}{
-		"/home/user/.local/share/chezmoi": map[string]interface{}{
+	chezmoitest.WithTestFS(t, map[string]any{
+		"/home/user/.local/share/chezmoi": map[string]any{
 			".chezmoiexternal.yaml": chezmoitest.JoinLines(
 				`.dir:`,
 				`    type: "archive"`,
@@ -1553,7 +1553,7 @@ func TestSourceStateReadExternalCache(t *testing.T) {
 func TestSourceStateTargetRelPaths(t *testing.T) {
 	for _, tc := range []struct {
 		name                   string
-		root                   interface{}
+		root                   any
 		expectedTargetRelPaths []RelPath
 	}{
 		{
@@ -1563,8 +1563,8 @@ func TestSourceStateTargetRelPaths(t *testing.T) {
 		},
 		{
 			name: "scripts",
-			root: map[string]interface{}{
-				"/home/user/.local/share/chezmoi": map[string]interface{}{
+			root: map[string]any{
+				"/home/user/.local/share/chezmoi": map[string]any{
 					"run_before_1before": "",
 					"run_before_2before": "",
 					"run_before_3before": "",
@@ -1667,7 +1667,7 @@ func withRemove(remove *patternSet) SourceStateOption {
 }
 
 // withUserTemplateData adds template data.
-func withUserTemplateData(templateData map[string]interface{}) SourceStateOption {
+func withUserTemplateData(templateData map[string]any) SourceStateOption {
 	return func(s *SourceState) {
 		RecursiveMerge(s.userTemplateData, templateData)
 	}
@@ -1679,8 +1679,8 @@ func withTemplates(templates map[string]*template.Template) SourceStateOption {
 	}
 }
 
-func manyScripts(amount int) map[string]interface{} {
-	scripts := map[string]interface{}{}
+func manyScripts(amount int) map[string]any {
+	scripts := map[string]any{}
 	for i := 0; i < amount; i++ {
 		scripts[fmt.Sprintf("run_onchange_before_%d.sh", i)] = ""
 	}
