@@ -73,7 +73,7 @@ type ConfigFile struct {
 	// Global configuration.
 	CacheDirAbsPath    chezmoi.AbsPath                 `json:"cacheDir" mapstructure:"cacheDir"`
 	Color              autoBool                        `mapstructure:"color"`
-	Data               map[string]interface{}          `mapstructure:"data"`
+	Data               map[string]any                  `mapstructure:"data"`
 	DestDirAbsPath     chezmoi.AbsPath                 `mapstructure:"destDir"`
 	Interpreters       map[string]*chezmoi.Interpreter `mapstructure:"interpreters"`
 	Mode               chezmoi.Mode                    `mapstructure:"mode"`
@@ -131,6 +131,7 @@ type Config struct {
 	force            bool
 	gops             bool
 	homeDir          string
+	interactive      bool
 	keepGoing        bool
 	noPager          bool
 	noTTY            bool
@@ -429,7 +430,7 @@ func newConfig(options ...configOption) (*Config, error) {
 		stderr: os.Stderr,
 	}
 
-	for key, value := range map[string]interface{}{
+	for key, value := range map[string]any{
 		"awsSecretsManager":        c.awsSecretsManagerTemplateFunc,
 		"awsSecretsManagerRaw":     c.awsSecretsManagerRawTemplateFunc,
 		"bitwarden":                c.bitwardenTemplateFunc,
@@ -438,10 +439,12 @@ func newConfig(options ...configOption) (*Config, error) {
 		"comment":                  c.commentTemplateFunc,
 		"decrypt":                  c.decryptTemplateFunc,
 		"encrypt":                  c.encryptTemplateFunc,
+		"fromIni":                  c.fromIniTemplateFunc,
 		"fromToml":                 c.fromTomlTemplateFunc,
 		"fromYaml":                 c.fromYamlTemplateFunc,
 		"gitHubKeys":               c.gitHubKeysTemplateFunc,
 		"gitHubLatestRelease":      c.gitHubLatestReleaseTemplateFunc,
+		"gitHubLatestTag":          c.gitHubLatestTagTemplateFunc,
 		"glob":                     c.globTemplateFunc,
 		"gopass":                   c.gopassTemplateFunc,
 		"gopassRaw":                c.gopassRawTemplateFunc,
@@ -473,6 +476,7 @@ func newConfig(options ...configOption) (*Config, error) {
 		"secret":                   c.secretTemplateFunc,
 		"secretJSON":               c.secretJSONTemplateFunc,
 		"stat":                     c.statTemplateFunc,
+		"toIni":                    c.toIniTemplateFunc,
 		"toToml":                   c.toTomlTemplateFunc,
 		"toYaml":                   c.toYamlTemplateFunc,
 		"vault":                    c.vaultTemplateFunc,
@@ -522,7 +526,7 @@ func (c *Config) Close() error {
 // addTemplateFunc adds the template function with the key key and value value
 // to c. It panics if there is already an existing template function with the
 // same key.
-func (c *Config) addTemplateFunc(key string, value interface{}) {
+func (c *Config) addTemplateFunc(key string, value any) {
 	if _, ok := c.templateFuncs[key]; ok {
 		panic(fmt.Sprintf("%s: already defined", key))
 	}
@@ -778,7 +782,7 @@ func (c *Config) createAndReloadConfigFile() error {
 func (c *Config) createConfigFile(filename chezmoi.RelPath, data []byte) ([]byte, error) {
 	funcMap := make(template.FuncMap)
 	chezmoi.RecursiveMerge(funcMap, c.templateFuncs)
-	initTemplateFuncs := map[string]interface{}{
+	initTemplateFuncs := map[string]any{
 		"exit":             c.exitInitTemplateFunc,
 		"promptBool":       c.promptBoolInitTemplateFunc,
 		"promptBoolOnce":   c.promptBoolOnceInitTemplateFunc,
@@ -846,13 +850,54 @@ func (c *Config) defaultPreApplyFunc(
 		Object("actualEntryState", actualEntryState).
 		Msg("defaultPreApplyFunc")
 
+	switch {
+	case c.force:
+		return nil
+	case targetEntryState.Equivalent(actualEntryState):
+		return nil
+	}
+
+	if c.interactive {
+		prompt := fmt.Sprintf("Apply %s", targetRelPath)
+		var choices []string
+		actualContents := actualEntryState.Contents()
+		targetContents := targetEntryState.Contents()
+		if actualContents != nil || targetContents != nil {
+			choices = append(choices, "diff")
+		}
+		choices = append(choices, choicesYesNoAllQuit...)
+		for {
+			switch choice, err := c.promptChoice(prompt, choices); {
+			case err != nil:
+				return err
+			case choice == "diff":
+				if err := c.diffFile(
+					targetRelPath,
+					actualContents, actualEntryState.Mode,
+					targetContents, targetEntryState.Mode,
+				); err != nil {
+					return err
+				}
+			case choice == "yes":
+				return nil
+			case choice == "no":
+				return chezmoi.Skip
+			case choice == "all":
+				c.interactive = false
+				return nil
+			case choice == "quit":
+				return chezmoi.ExitCodeError(0)
+			default:
+				panic(fmt.Sprintf("%s: unexpected choice", choice))
+			}
+		}
+	}
+
 	switch {
 	case targetEntryState.Overwrite():
 		return nil
 	case targetEntryState.Type == chezmoi.EntryStateTypeScript:
 		return nil
-	case c.force:
-		return nil
 	case lastWrittenEntryState == nil:
 		return nil
 	case lastWrittenEntryState.Equivalent(actualEntryState):
@@ -917,7 +962,7 @@ func (c *Config) defaultSourceDir(fileSystem vfs.Stater, bds *xdg.BaseDirectoryS
 }
 
 // defaultTemplateData returns the default template data.
-func (c *Config) defaultTemplateData() map[string]interface{} {
+func (c *Config) defaultTemplateData() map[string]any {
 	// Determine the user's username and group, if possible.
 	//
 	// user.Current and user.LookupGroupId in Go's standard library are
@@ -978,7 +1023,7 @@ func (c *Config) defaultTemplateData() map[string]interface{} {
 			Err(err).
 			Msg("chezmoi.FQDNHostname")
 	}
-	hostname, _, _ := chezmoi.CutString(fqdnHostname, ".")
+	hostname, _, _ := strings.Cut(fqdnHostname, ".")
 
 	kernel, err := chezmoi.Kernel(c.fileSystem)
 	if err != nil {
@@ -987,7 +1032,7 @@ func (c *Config) defaultTemplateData() map[string]interface{} {
 			Msg("chezmoi.Kernel")
 	}
 
-	var osRelease map[string]interface{}
+	var osRelease map[string]any
 	switch runtime.GOOS {
 	case "openbsd", "windows":
 		// Don't populate osRelease on OSes where /etc/os-release does not
@@ -1006,8 +1051,8 @@ func (c *Config) defaultTemplateData() map[string]interface{} {
 
 	windowsVersion, _ := c.windowsVersion()
 
-	return map[string]interface{}{
-		"chezmoi": map[string]interface{}{
+	return map[string]any{
+		"chezmoi": map[string]any{
 			"arch":         runtime.GOARCH,
 			"args":         os.Args,
 			"cacheDir":     c.CacheDirAbsPath.String(),
@@ -1024,7 +1069,7 @@ func (c *Config) defaultTemplateData() map[string]interface{} {
 			"sourceDir":    c.SourceDirAbsPath.String(),
 			"uid":          uid,
 			"username":     username,
-			"version": map[string]interface{}{
+			"version": map[string]any{
 				"builtBy": c.versionInfo.BuiltBy,
 				"commit":  c.versionInfo.Commit,
 				"date":    c.versionInfo.Date,
@@ -1142,7 +1187,7 @@ func (c *Config) editor(args []string) (string, []string, error) {
 }
 
 // errorf writes an error to stderr.
-func (c *Config) errorf(format string, args ...interface{}) {
+func (c *Config) errorf(format string, args ...any) {
 	fmt.Fprintf(c.stderr, "chezmoi: "+format, args...)
 }
 
@@ -1286,7 +1331,7 @@ func (c *Config) makeRunEWithSourceState(
 }
 
 // marshal formats data in dataFormat and writes it to the standard output.
-func (c *Config) marshal(dataFormat writeDataFormat, data interface{}) error {
+func (c *Config) marshal(dataFormat writeDataFormat, data any) error {
 	var format chezmoi.Format
 	switch dataFormat {
 	case writeDataFormatJSON:
@@ -1353,6 +1398,7 @@ func (c *Config) newRootCmd() (*cobra.Command, error) {
 	persistentFlags.BoolVarP(&c.dryRun, "dry-run", "n", c.dryRun, "Do not make any modifications to the destination directory") //nolint:lll
 	persistentFlags.BoolVar(&c.force, "force", c.force, "Make all changes without prompting")
 	persistentFlags.BoolVar(&c.gops, "gops", c.gops, "Enable gops agent")
+	persistentFlags.BoolVar(&c.interactive, "interactive", c.interactive, "Prompt for all changes")
 	persistentFlags.BoolVarP(&c.keepGoing, "keep-going", "k", c.keepGoing, "Keep going as far as possible after an error")
 	persistentFlags.BoolVar(&c.noPager, "no-pager", c.noPager, "Do not use the pager")
 	persistentFlags.BoolVar(&c.noTTY, "no-tty", c.noTTY, "Do not attempt to get a TTY for reading passwords")
@@ -1443,6 +1489,7 @@ func (c *Config) newDiffSystem(s chezmoi.System, w io.Writer, dirAbsPath chezmoi
 		return chezmoi.NewGitDiffSystem(s, w, dirAbsPath, options)
 	}
 	options := &chezmoi.ExternalDiffSystemOptions{
+		Include: c.Diff.include.Sub(c.Diff.Exclude),
 		Reverse: c.Diff.Reverse,
 	}
 	return chezmoi.NewExternalDiffSystem(s, c.Diff.Command, c.Diff.Args, c.DestDirAbsPath, options)
