@@ -3,6 +3,7 @@ package cmd
 import (
 	"errors"
 	"fmt"
+	"io"
 	"io/fs"
 	"os"
 	"os/exec"
@@ -10,9 +11,14 @@ import (
 	"regexp"
 	"runtime"
 	"strconv"
+	"strings"
 
 	"github.com/bmatcuk/doublestar/v4"
 	"github.com/bradenhilton/mozillainstallhash"
+	"golang.org/x/exp/constraints"
+	"golang.org/x/exp/maps"
+	"golang.org/x/exp/slices"
+	"gopkg.in/ini.v1"
 	"howett.net/plist"
 
 	"github.com/twpayne/chezmoi/v2/pkg/chezmoi"
@@ -20,7 +26,7 @@ import (
 )
 
 type ioregData struct {
-	value map[string]interface{}
+	value map[string]any
 }
 
 var startOfLineRx = regexp.MustCompile(`(?m)^`)
@@ -29,16 +35,24 @@ func (c *Config) commentTemplateFunc(prefix, s string) string {
 	return startOfLineRx.ReplaceAllString(s, prefix)
 }
 
-func (c *Config) fromTomlTemplateFunc(s string) interface{} {
-	var data interface{}
+func (c *Config) fromIniTemplateFunc(s string) map[string]any {
+	file, err := ini.Load([]byte(s))
+	if err != nil {
+		panic(err)
+	}
+	return iniFileToMap(file)
+}
+
+func (c *Config) fromTomlTemplateFunc(s string) any {
+	var data any
 	if err := chezmoi.FormatTOML.Unmarshal([]byte(s), &data); err != nil {
 		panic(err)
 	}
 	return data
 }
 
-func (c *Config) fromYamlTemplateFunc(s string) interface{} {
-	var data interface{}
+func (c *Config) fromYamlTemplateFunc(s string) any {
+	var data any
 	if err := chezmoi.FormatYAML.Unmarshal([]byte(s), &data); err != nil {
 		panic(err)
 	}
@@ -90,7 +104,7 @@ func (c *Config) includeTemplateFunc(filename string) string {
 	return string(contents)
 }
 
-func (c *Config) ioregTemplateFunc() map[string]interface{} {
+func (c *Config) ioregTemplateFunc() map[string]any {
 	if runtime.GOOS != "darwin" {
 		return nil
 	}
@@ -108,7 +122,7 @@ func (c *Config) ioregTemplateFunc() map[string]interface{} {
 		panic(newCmdOutputError(cmd, output, err))
 	}
 
-	var value map[string]interface{}
+	var value map[string]any
 	if _, err := plist.Unmarshal(output, &value); err != nil {
 		panic(newParseCmdOutputError(command, args, output, err))
 	}
@@ -153,7 +167,7 @@ func (c *Config) outputTemplateFunc(name string, args ...string) string {
 	return string(output)
 }
 
-func (c *Config) quoteListTemplateFunc(list []interface{}) []string {
+func (c *Config) quoteListTemplateFunc(list []any) []string {
 	result := make([]string, 0, len(list))
 	for _, elem := range list {
 		var elemStr string
@@ -178,10 +192,10 @@ func (c *Config) replaceAllRegexTemplateFunc(expr, repl, s string) string {
 	return regexp.MustCompile(expr).ReplaceAllString(s, repl)
 }
 
-func (c *Config) statTemplateFunc(name string) interface{} {
+func (c *Config) statTemplateFunc(name string) any {
 	switch fileInfo, err := c.fileSystem.Stat(name); {
 	case err == nil:
-		return map[string]interface{}{
+		return map[string]any{
 			"name":    fileInfo.Name(),
 			"size":    fileInfo.Size(),
 			"mode":    int(fileInfo.Mode()),
@@ -196,7 +210,15 @@ func (c *Config) statTemplateFunc(name string) interface{} {
 	}
 }
 
-func (c *Config) toTomlTemplateFunc(data interface{}) string {
+func (c *Config) toIniTemplateFunc(data map[string]interface{}) string {
+	var builder strings.Builder
+	if err := writeIniMap(&builder, data, ""); err != nil {
+		panic(err)
+	}
+	return builder.String()
+}
+
+func (c *Config) toTomlTemplateFunc(data any) string {
 	toml, err := chezmoi.FormatTOML.Marshal(data)
 	if err != nil {
 		panic(err)
@@ -204,10 +226,76 @@ func (c *Config) toTomlTemplateFunc(data interface{}) string {
 	return string(toml)
 }
 
-func (c *Config) toYamlTemplateFunc(data interface{}) string {
+func (c *Config) toYamlTemplateFunc(data any) string {
 	yaml, err := chezmoi.FormatYAML.Marshal(data)
 	if err != nil {
 		panic(err)
 	}
 	return string(yaml)
 }
+
+func iniFileToMap(file *ini.File) map[string]any {
+	m := make(map[string]any)
+	for _, section := range file.Sections() {
+		m[section.Name()] = iniSectionToMap(section)
+	}
+	return m
+}
+
+func iniSectionToMap(section *ini.Section) map[string]any {
+	m := make(map[string]any)
+	for _, s := range section.ChildSections() {
+		m[s.Name()] = iniSectionToMap(s)
+	}
+	for _, k := range section.Keys() {
+		m[k.Name()] = k.Value()
+	}
+	return m
+}
+
+func writeIniMap(w io.Writer, data map[string]any, sectionPrefix string) error {
+	// Write keys in order and accumulate subsections.
+	type subsection struct {
+		key   string
+		value map[string]any
+	}
+	var subsections []subsection
+	for _, key := range sortedKeys(data) {
+		switch value := data[key].(type) {
+		case bool:
+			fmt.Fprintf(w, "%s = %t\n", key, value)
+		case float32, float64:
+			fmt.Fprintf(w, "%s = %f\n", key, value)
+		case int, int8, int16, int32, int64, uint, uint8, uint16, uint32, uint64, uintptr:
+			fmt.Fprintf(w, "%s = %d\n", key, value)
+		case map[string]any:
+			subsection := subsection{
+				key:   key,
+				value: value,
+			}
+			subsections = append(subsections, subsection)
+		case string:
+			fmt.Fprintf(w, "%s = %q\n", key, value)
+		default:
+			return fmt.Errorf("%s%s: %T: unsupported type", sectionPrefix, key, value)
+		}
+	}
+
+	// Write subsections in order.
+	for _, subsection := range subsections {
+		if _, err := fmt.Fprintf(w, "\n[%s%s]\n", sectionPrefix, subsection.key); err != nil {
+			return err
+		}
+		if err := writeIniMap(w, subsection.value, sectionPrefix+subsection.key+"."); err != nil {
+			return err
+		}
+	}
+
+	return nil
+}
+
+func sortedKeys[K constraints.Ordered, V any](m map[K]V) []K {
+	keys := maps.Keys(m)
+	slices.Sort(keys)
+	return keys
+}
